voicetools.iterate_semantic_voices_forward_in_expr
==================================================

.. autofunction:: abjad.tools.voicetools.iterate_semantic_voices_forward_in_expr.iterate_semantic_voices_forward_in_expr
